@@ -65,6 +65,7 @@ class TestTerminalState:
         await state.on_pending_order_updated('1:ps-mpa-1', {'id': '1', 'openPrice': 10})
         await state.on_pending_order_updated('1:ps-mpa-1', {'id': '2'})
         await state.on_pending_order_updated('1:ps-mpa-1', {'id': '1', 'openPrice': 11})
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         assert len(state.orders) == 2
         await state.on_pending_order_completed('1:ps-mpa-1', '2')
         assert len(state.orders) == 1
@@ -119,6 +120,7 @@ class TestTerminalState:
             'profit': 100,
             'volume': 2
         }])
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         await state.on_position_updated('1:ps-mpa-1', {
             'id': '2',
             'symbol': 'AUDUSD',
@@ -202,7 +204,6 @@ class TestTerminalState:
         assert state.price('EURUSD') == {'time': datetime.fromtimestamp(1000000),
                                          'symbol': 'EURUSD', 'bid': 1, 'ask': 1.1}
         await state.on_stream_closed('1:ps-mpa-1')
-        assert not state.price('EURUSD')
 
     @pytest.mark.asyncio
     async def test_on_synchronization_started(self):
@@ -232,27 +233,30 @@ class TestTerminalState:
         assert state.specification('EURUSD') == specification
         await state.on_synchronization_started('1:ps-mpa-1', specifications_updated=False, positions_updated=False,
                                                orders_updated=False)
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         assert not state.account_information
         assert state.specification('EURUSD') == specification
         assert state.orders == orders
         assert state.positions == positions
         await state.on_synchronization_started('1:ps-mpa-1', specifications_updated=True, positions_updated=False,
                                                orders_updated=False)
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         assert not state.specification('EURUSD')
         assert state.orders == orders
         assert state.positions == positions
         await state.on_synchronization_started('1:ps-mpa-1', specifications_updated=True, positions_updated=False,
                                                orders_updated=True)
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         assert state.orders == []
         assert state.positions == positions
         await state.on_synchronization_started('1:ps-mpa-1', specifications_updated=True, positions_updated=True,
                                                orders_updated=True)
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         assert state.positions == []
 
     @pytest.mark.asyncio
     async def test_return_hashes_g1(self):
         """Should return hashes for terminal state data for cloud-g1 accounts."""
-        empty_hash = 'd751713988987e9331980363e24189ce'
         specifications_hash = md5(
             ('[{"symbol":"AUDNZD","tickSize":0.01000000},{"symbol":"EURUSD",'
              '"tickSize":0.00000100,"contractSize":1.00000000,"maxVolume":30000.00000000,'
@@ -266,9 +270,9 @@ class TestTerminalState:
                            '"symbol":"AUDNZD","magic":123456,"platform":"mt5","openPrice":1.03000000,'
                            '"volume":0.01000000,"currentVolume":0.01000000}]').encode()).hexdigest()
         hashes = state.get_hashes('cloud-g1')
-        assert hashes['specificationsMd5'] == empty_hash
-        assert hashes['positionsMd5'] == empty_hash
-        assert hashes['ordersMd5'] == empty_hash
+        assert hashes['specificationsMd5'] is None
+        assert hashes['positionsMd5'] is None
+        assert hashes['ordersMd5'] is None
         await state.on_symbol_specifications_updated('1:ps-mpa-1', [
             {'symbol': 'AUDNZD', 'tickSize': 0.01, "description": "Test1"},
             {'symbol': 'EURUSD', 'tickSize': 0.000001, "contractSize": 1, "maxVolume": 30000,
@@ -294,7 +298,7 @@ class TestTerminalState:
             'updateSequenceNumber': 13246,
             'accountCurrencyExchangeRate': 1,
             'comment': 'test',
-            'originalComment': 'test2',
+            'brokerComment': 'test2',
         }])
         await state.on_pending_orders_replaced('1:ps-mpa-1', [{
             'id': '46871284',
@@ -311,9 +315,10 @@ class TestTerminalState:
             'comment': 'COMMENT2',
             'updateSequenceNumber': 13246,
             'accountCurrencyExchangeRate': 1,
-            'originalComment': 'test2',
+            'brokerComment': 'test2',
             'clientId': 'TE_GBPUSD_7hyINWqAlE',
         }])
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         hashes = state.get_hashes('cloud-g1')
         assert hashes['specificationsMd5'] == specifications_hash
         assert hashes['positionsMd5'] == positions_hash
@@ -322,7 +327,6 @@ class TestTerminalState:
     @pytest.mark.asyncio
     async def test_return_hashes_g2(self):
         """Should return hashes for terminal state data for cloud-g2 accounts."""
-        empty_hash = 'd751713988987e9331980363e24189ce'
         specifications_hash = md5(
             ('[{"symbol":"AUDNZD","tickSize":0.01,"description":"Test1"},{"symbol":"EURUSD","tickSize":0.000001,'
              '"contractSize":1,"maxVolume":30000,"hedgedMarginUsesLargerLeg":false,"description":"Test2"}]'
@@ -335,9 +339,9 @@ class TestTerminalState:
                            '"symbol":"AUDNZD","magic":123456,"platform":"mt5","time":"2020-04-20T08:38:58.270Z",'
                            '"openPrice":1.03,"volume":0.01,"currentVolume":0.01}]').encode()).hexdigest()
         hashes = state.get_hashes('cloud-g2')
-        assert hashes['specificationsMd5'] == empty_hash
-        assert hashes['positionsMd5'] == empty_hash
-        assert hashes['ordersMd5'] == empty_hash
+        assert hashes['specificationsMd5'] is None
+        assert hashes['positionsMd5'] is None
+        assert hashes['ordersMd5'] is None
         await state.on_symbol_specifications_updated('1:ps-mpa-1', [
             {'symbol': 'AUDNZD', 'tickSize': 0.01, "description": "Test1"},
             {'symbol': 'EURUSD', 'tickSize': 0.000001, "contractSize": 1, "maxVolume": 30000,
@@ -363,7 +367,7 @@ class TestTerminalState:
             'updateSequenceNumber': 13246,
             'accountCurrencyExchangeRate': 1,
             'comment': 'test',
-            'originalComment': 'test2',
+            'brokerComment': 'test2',
         }])
         await state.on_pending_orders_replaced('1:ps-mpa-1', [{
             'id': '46871284',
@@ -380,9 +384,10 @@ class TestTerminalState:
             'comment': 'COMMENT2',
             'updateSequenceNumber': 13246,
             'accountCurrencyExchangeRate': 1,
-            'originalComment': 'test2',
+            'brokerComment': 'test2',
             'clientId': 'TE_GBPUSD_7hyINWqAlE',
         }])
+        await state.on_pending_orders_synchronized('1:ps-mpa-1', 'synchronizationId')
         hashes = state.get_hashes('cloud-g2')
         assert hashes['specificationsMd5'] == specifications_hash
         assert hashes['positionsMd5'] == positions_hash
